@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -18,9 +21,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-openapigateway-lambda",
-    "2.52.1",
+    "2.63.0",
     __name__[0:-6],
-    "aws-openapigateway-lambda@2.52.1.jsii.tgz",
+    "aws-openapigateway-lambda@2.63.0.jsii.tgz",
 )
 
 __all__ = [
